%global upstreamver 2023-12-09

Name:           limnoria
Version:        20231209
Release:        %mkrel 1
Summary:        A modified version of Supybot (an IRC bot) with enhancements and bug fixes
Group:          Networking/IRC
License:        BSD and GPLv2 and GPLv2+
#
# The bulk of the package is BSD.
# Parts of the Math plugin are GPLv2+
# The Dict plugin is GPLv2+
#
URL:            https://github.com/ProgVal/Limnoria
Source0:        https://github.com/progval/Limnoria/archive/refs/tags/master-%{upstreamver}.tar.gz

BuildArch:      noarch

# Provide the upper case version also to avoid confusion
Provides:       Limnoria = %{version}-%{release}
Provides:       supybot = %{version}-%{release}

BuildRequires:  python3-devel
BuildRequires:  python3-chardet
BuildRequires:  python3-pytz
BuildRequires:  python3-dateutil
BuildRequires:  python3-gnupg
BuildRequires:  python3-feedparser
BuildRequires:  python3-sqlalchemy
BuildRequires:  python3-pysocks
BuildRequires:  python3-mock
BuildRequires:  python3-ecdsa

Requires:  python3-chardet
Requires:  python3-pytz
Requires:  python3-dateutil
Requires:  python3-gnupg
Requires:  python3-feedparser
Requires:  python3-sqlalchemy
Requires:  python3-pysocks
Requires:  python3-mock
Requires:  python3-ecdsa

%description
Supybot is a robust (it doesn't crash), user friendly 
(it's easy to configure) and programmer friendly 
(plugins are extremely easy to write) Python IRC bot.
It aims to be an adequate replacement for most existing IRC bots.
It includes a very flexible and powerful ACL system for controlling 
access to commands, as well as more than 50 built-in plugins 
providing around 400 actual commands.

Limnoria is a project which continues development of Supybot 
(you can call it a fork) by fixing bugs and adding features 
(see the list of added features for more details).

%prep
%autosetup -n Limnoria-master-%{upstreamver}

%build
# remove stray python bits from debug plugin
sed -i 1"s|#!/usr/bin/python||" plugins/Debug/plugin.py

# This should be set to the day of the release. 
# It's gets added as 'version' and is based on build time, not release time.
SOURCE_DATE_EPOCH=`date --date=%{version} +\%s`
export SOURCE_DATE_EPOCH

%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files supybot

%files -f %{pyproject_files}
%doc ChangeLog CONTRIBUTING.md README.md RELNOTES
%license LICENSE.md
%{_bindir}/limnoria
%{_bindir}/limnoria-adduser
%{_bindir}/limnoria-botchk
%{_bindir}/limnoria-plugin-create
%{_bindir}/limnoria-plugin-doc
%{_bindir}/limnoria-reset-password
%{_bindir}/limnoria-test
%{_bindir}/limnoria-wizard
%{_mandir}/man1/limnoria-adduser.1.*
%{_mandir}/man1/limnoria-botchk.1.*
%{_mandir}/man1/limnoria-plugin-create.1.*
%{_mandir}/man1/limnoria-plugin-doc.1.*
%{_mandir}/man1/limnoria-reset-password.1.*
%{_mandir}/man1/limnoria-test.1.*
%{_mandir}/man1/limnoria-wizard.1.*
%{_mandir}/man1/limnoria.1.*

%{_bindir}/supybot
%{_bindir}/supybot-adduser
%{_bindir}/supybot-botchk
%{_bindir}/supybot-plugin-create
%{_bindir}/supybot-plugin-doc
%{_bindir}/supybot-test
%{_bindir}/supybot-wizard
%{_bindir}/supybot-reset-password
%{_mandir}/man1/supybot-adduser.1.*
%{_mandir}/man1/supybot-botchk.1.*
%{_mandir}/man1/supybot-plugin-create.1.*
%{_mandir}/man1/supybot-plugin-doc.1.*
%{_mandir}/man1/supybot-test.1.*
%{_mandir}/man1/supybot-wizard.1.*
%{_mandir}/man1/supybot.1.*
%{_mandir}/man1/supybot-reset-password.1.*


%changelog
* Mon Jan 01 2024 daviddavid <daviddavid> 20231209-1.mga10
+ Revision: 2025018
- new version: 20231209
- switch to pyproject
+ papoteur <papoteur>
- Mass Rebuild - Python 3.12

* Tue Jan 17 2023 daviddavid <daviddavid> 20230112-1.mga9
+ Revision: 1934109
- new version: 20230112

* Sun Oct 09 2022 neoclust <neoclust> 20220703-1.mga9
+ Revision: 1895755
- New version 20220703

* Fri Mar 25 2022 umeabot <umeabot> 20220203-2.mga9
+ Revision: 1825699
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 20220203-1.mga9
+ Revision: 1787087
- rebuild for python-3.10

* Thu Nov 04 2021 neoclust <neoclust> 20211009-1.mga9
+ Revision: 1753961
- New version 2021-10-09

* Thu Nov 04 2021 neoclust <neoclust> 20210527-1.mga9
+ Revision: 1753955
- imported package limnoria


* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 20210527-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 20210527-3
- Rebuilt for Python 3.10

* Sat May 29 2021 Kevin Fenzi <kevin@scrye.com> - 20210527-2
- Fix changelog

* Sat May 29 2021 Kevin Fenzi <kevin@scrye.com> - 20210527-1
- Upgrade to 20210527

* Fri May 28 2021 Simo Sorce <simo@fedoraproject.org> - 20210411-2
- Fix version string forever by calculating it

* Sat Apr 24 2021 Kevin Fenzi <kevin@scrye.com> - 20210411-1
- Upgrade to 20210411.

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 20201013-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Nov 03 2020 Kevin Fenzi <kevin@scrye.com> - 20201013-1
- Update to 20201013.

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 20200701-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sun Jul 12 2020 Kevin Fenzi <kevin@scrye.com> - 20200701-1
- Update to 20200701.

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 20200319-2
- Rebuilt for Python 3.9

* Sun Apr 05 2020 Kevin Fenzi <kevin@scrye.com> - 20200319-1
- Update to 20200319. 

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 20191109-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sun Nov 10 2019 Kevin Fenzi <kevin@scrye.com> - 20191109-2
- Fix incorrect version reporting.

* Sat Nov 09 2019 Kevin Fenzi <kevin@scrye.com> - 20191109-1
- Update to 2019-11-09

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 20180625.2-6
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 20180625.2-5
- Rebuilt for Python 3.8

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 20180625.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 20180625.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Sep 02 2018 Kevin Fenzi <kevin@scrye.com> - 20180625.2-2
- Switch to python3 by default in f29+

* Fri Jul 20 2018 Kevin Fenzi <kevin@scrye.com> - 20180625.2-1
- Update to 2018-06-25-2

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 20171025-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Mar 01 2018 Iryna Shcherbina <ishcherb@redhat.com> - 20171025-3
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 20171025-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Dec 01 2017 Kevin Fenzi <kevin@scrye.com> - 20171025-1
- Update to 20171025.

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 20170127-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Feb 07 2017 Kevin Fenzi <kevin@scrye.com> - 20170127-1
- Update to 20170127

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20160506-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Jun 07 2016 Kevin Fenzi <kevin@scrye.com> - 20160506-2
- Updates from review: Fixed license
- Added Run time requires for needed python packages. 

* Sat Jun 04 2016 Kevin Fenzi <kevin@scrye.com> - 20160506-1
- Initial Fedora/EPEL version
